@@ -1,4 +1,3 @@
-
 from typing import Iterator, Dict
 from pathlib import Path
 
@@ -16,8 +15,8 @@ def is_ili(source: AnyPath) -> bool:
     source = Path(source).expanduser()
     if source.is_file():
         try:
-            with source.open('rb') as fh:
-                return next(fh).split(b'\t')[0] in (b'ili', b'ILI')
+            with source.open("rb") as fh:
+                return next(fh).split(b"\t")[0] in (b"ili", b"ILI")
         except (StopIteration, IndexError):
             pass
     return False
@@ -30,8 +29,8 @@ def load(source: AnyPath) -> Iterator[Dict[str, str]]:
         source: path to an ILI file
     """
     source = Path(source).expanduser()
-    with source.open(encoding='utf-8') as fh:
-        header = next(fh).rstrip('\r\n')
-        fields = tuple(map(str.lower, header.split('\t')))
+    with source.open(encoding="utf-8") as fh:
+        header = next(fh).rstrip("\r\n")
+        fields = tuple(map(str.lower, header.split("\t")))
         for line in fh:
-            yield dict(zip(fields, line.rstrip('\r\n').split('\t')))
+            yield dict(zip(fields, line.rstrip("\r\n").split("\t")))
